@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 """
 Convert IRC logs to HTML.
 
@@ -45,8 +44,6 @@ was written by Jeff Waugh and is available at www.perkypants.org
 #   New default style: xhtmltable
 #
 
-from __future__ import print_function, unicode_literals
-
 import datetime
 import gzip
 import io
@@ -58,25 +55,13 @@ import re
 import shlex
 import shutil
 import sys
-
-
-try:
-    from urllib import quote
-except ImportError:
-    from urllib.parse import quote
+from urllib.parse import quote
 
 from ._version import __date__ as RELEASE
 from ._version import __homepage__ as HOMEPAGE
 from ._version import __version__ as VERSION
 
 
-try:
-    unicode
-except NameError:
-    # Python 3.x
-    unicode = str
-
-
 # If someone packages this for a Linux distro, they'll want to patch this to
 # something like /usr/share/irclog2html/irclog.css, I imagine
 CSS_FILE = os.path.join(os.path.dirname(__file__), 'irclog.css')
@@ -145,7 +130,7 @@ class LogParser(object):
         Supports xchat's hybrid Latin/Unicode encoding, as documented here:
         http://xchat.org/encoding/
         """
-        if isinstance(s, unicode):
+        if isinstance(s, str):
             # Accept input that's already Unicode, for convenience
             return s
         try:
@@ -169,8 +154,9 @@ class LogParser(object):
             if time is None:
                 m = self.TIMESTAMP_REGEXP.match(line)
                 if m:
-                    time = datetime.datetime.utcfromtimestamp(
-                        int(m.group(1))).isoformat()
+                    time = datetime.datetime.fromtimestamp(
+                        int(m.group(1)), datetime.timezone.utc
+                    ).strftime('%Y-%m-%dT%H:%M:%S')
                     line = line[len(m.group(0)):]
 
             m = self.NICK_REGEXP.match(line)
@@ -205,7 +191,7 @@ def open_log_file(filename):
     if filename.endswith('.gz'):
         return gzip.open(filename, 'rb')
     else:
-        return io.open(filename, 'rb')
+        return open(filename, 'rb')
 
 
 def shorttime(time):
@@ -952,7 +938,7 @@ def main(argv=sys.argv):
         else:
             outfilename = options.output_file
         try:
-            outfile = io.open(outfilename, "wb")
+            outfile = open(outfilename, "wb")
         except EnvironmentError as e:
             infile.close()
             sys.exit("%s: cannot open %s for writing: %s"
