@@ -1,7 +1,4 @@
-from __future__ import print_function
-
 import doctest
-import io
 import os
 import shutil
 import sys
@@ -26,29 +23,9 @@ from irclog2html.irclog2html import (
 )
 
 
-try:
-    unicode
-except NameError:
-    # Python 3.x
-    unicode = str
-
-
 here = os.path.dirname(__file__)
 
 
-def myrepr(o):
-    """Repr that drops u prefixes on unicode strings."""
-    if isinstance(o, tuple):
-        if len(o) == 1:
-            return '(%s, )' % ', '.join(map(myrepr, o))
-        else:
-            return '(%s)' % ', '.join(map(myrepr, o))
-    elif isinstance(o, unicode):
-        return repr(o).lstrip('u')
-    else:
-        return repr(o)
-
-
 def doctest_LogParser():
     r"""Tests for LogParser
 
@@ -56,7 +33,7 @@ def doctest_LogParser():
 
         >>> def test(line):
         ...     for time, what, info in LogParser([line]):
-        ...         print(myrepr(time), what, myrepr(info))
+        ...         print(repr(time), what, repr(info))
 
     LogParser ignores empty lines
 
@@ -181,7 +158,7 @@ def doctest_LogParser_dircproxy_support():
 
         >>> def test(line):
         ...     for time, what, info in LogParser([line], dircproxy=True):
-        ...         print(myrepr(time), what, myrepr(info))
+        ...         print(repr(time), what, repr(info))
 
         >>> test('[15 Jan 08:42] <mg!n=user@10.0.0.1> -hmm')
         '15 Jan 08:42' COMMENT ('mg', 'hmm')
@@ -206,7 +183,7 @@ def doctest_LogParser_encodings():
 
         >>> def test(line):
         ...     for time, what, info in LogParser([line]):
-        ...         print(myrepr(time), what, myrepr(info))
+        ...         print(repr(time), what, repr(info))
 
     We accept input that's in UTF-8
 
@@ -739,7 +716,7 @@ def run(*args):
         main(['irclog2html'] + list(args))
     except SystemExit as e:
         if e.args[0] != 0:
-            print("SystemExit(%s)" % myrepr(e.args[0]))
+            print("SystemExit(%s)" % repr(e.args[0]))
     finally:
         sys.stderr = stderr
 
@@ -816,7 +793,7 @@ def doctest_main():
         >>> fn = os.path.join(tmpdir, 'sample.log')
         >>> _ = shutil.copyfile(os.path.join(here, 'sample.log'), fn)
         >>> run(fn)
-        >>> with io.open(fn + '.html', encoding='UTF-8') as f:
+        >>> with open(fn + '.html', encoding='UTF-8') as f:
         ...     print(f.read())
         <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
                   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
@@ -886,7 +863,7 @@ def doctest_main_output_file():
         >>> fn = os.path.join(here, 'sample.log')
         >>> outfn = os.path.join(tmpdir, 'output.html')
         >>> run(fn, '-o', outfn)
-        >>> with io.open(outfn, encoding='UTF-8') as f:
+        >>> with open(outfn, encoding='UTF-8') as f:
         ...     print(f.read())
         <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
                   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
@@ -903,7 +880,7 @@ def doctest_main_output_directory():
         >>> fn = os.path.join(here, 'sample.log')
         >>> run(fn, '-o', tmpdir)
         >>> outfn = os.path.join(tmpdir, 'sample.log.html')
-        >>> with io.open(outfn, encoding='UTF-8') as f:
+        >>> with open(outfn, encoding='UTF-8') as f:
         ...     print(f.read())
         <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
                   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
