@@ -1,17 +1,13 @@
-import cgi
 import datetime
 import doctest
 import gzip
 import os
-import re
 import shutil
 import sys
 import tempfile
 import unittest
 from contextlib import closing
-
-import mock
-from zope.testing import renormalizing
+from unittest import mock
 
 from irclog2html.irclogsearch import (
     LogParser,
@@ -26,10 +22,9 @@ from irclog2html.irclogsearch import (
 
 
 try:
-    unicode
-except NameError:
-    # Python 3.x
-    unicode = str
+    import cgi
+except ImportError:
+    cgi = None
 
 
 here = os.path.dirname(__file__)
@@ -60,11 +55,10 @@ class BytesIOWrapper(object):
 
 
 def prepare_stdout():
-    if sys.version_info[0] >= 3:
-        # Make the StringIO used by doctest act like the real sys.stdout, which
-        # has an underlying bytes-only output stream.  This is needed because
-        # we're going to print bytes in this CGI script.
-        sys.stdout.buffer = BytesIOWrapper(sys.stdout)
+    # Make the StringIO used by doctest act like the real sys.stdout, which
+    # has an underlying bytes-only output stream.  This is needed because
+    # we're going to print bytes in this CGI script.
+    sys.stdout.buffer = BytesIOWrapper(sys.stdout)
 
 
 def myrepr(o):
@@ -74,12 +68,19 @@ def myrepr(o):
             return '(%s, )' % ', '.join(map(myrepr, o))
         else:
             return '(%s)' % ', '.join(map(myrepr, o))
-    elif isinstance(o, unicode):
-        return repr(o).lstrip('u')
     else:
         return repr(o)
 
 
+def skipIf(condition: bool):
+    """Skip a doctest if condition is false."""
+    def wrapper(fn):
+        if condition:
+            return None
+        return fn
+    return wrapper
+
+
 def doctest_SearchResultFormatter():
     """Test for SearchResultFormatter
 
@@ -262,18 +263,14 @@ def doctest_search_page():
 
     When there is a 'q' param in the GET query, the logs are searched:
 
-        >>> form = cgi.FieldStorage(
-        ...     environ={'QUERY_STRING': 'q=123', 'HTTP_METHOD': 'GET'})
-        >>> search_page("The stream", form, "/logs", "#dev*.logs")
+        >>> search_page("The stream", '123', "/logs", "#dev*.logs")
         >>> values['print_search_results'].assert_called_once_with(
         ...     '123', logfile_pattern='#dev*.logs',
         ...     stream='The stream', where='/logs')
 
     When there is no query, the search form is displayed:
 
-        >>> form = cgi.FieldStorage(environ={
-        ...     'HTTP_METHOD': 'GET', 'QUERY_STRING': ''})
-        >>> search_page("The stream", form, "/logs", "#dev*.logs")
+        >>> search_page("The stream", None, "/logs", "#dev*.logs")
         >>> values['print_search_form'].assert_called_once_with('The stream')
 
     Clean up:
@@ -283,6 +280,7 @@ def doctest_search_page():
     """
 
 
+@skipIf(cgi is None)
 def doctest_main_prints_form():
     """Test for main
 
@@ -319,6 +317,7 @@ def doctest_main_prints_form():
     """
 
 
+@skipIf(cgi is None)
 def doctest_main_searches():
     r"""Test for main
 
@@ -378,19 +377,11 @@ def doctest_main_searches():
     """
 
 
-checker = None
-if sys.version_info[0] == 2:
-    checker = renormalizing.RENormalizing([
-        (re.compile(r"^\['"), r"[b'"),
-        (re.compile(r"u('.*?')"), r"\1"),
-    ])
-
-
 def test_suite():
     optionflags = (doctest.ELLIPSIS | doctest.REPORT_NDIFF |
                    doctest.NORMALIZE_WHITESPACE)
     return unittest.TestSuite([
-        doctest.DocTestSuite(optionflags=optionflags, checker=checker),
+        doctest.DocTestSuite(optionflags=optionflags),
     ])
 
 
