@@ -137,8 +137,6 @@ class TestLogFile(TestCase):
 
     def test_move_symlink(self):
         if not hasattr(os, 'symlink'):
-            if not hasattr(self, 'skipTest'): # Python 2.6
-                return
             self.skipTest("platform does not support symlinks")
         move_symlink('somechannel-20130316.log.html',
                      self.filename('latest.log.html'))
@@ -350,5 +348,5 @@ def doctest_main_extra_args():
 def test_suite():
     return unittest.TestSuite([
         doctest.DocTestSuite(optionflags=doctest.ELLIPSIS | doctest.REPORT_NDIFF),
-        unittest.makeSuite(TestLogFile),
+        unittest.defaultTestLoader.loadTestsFromName(__name__),
     ])
